@@ -18,10 +18,11 @@
 //! it's a modified version of hdfs-rs
 use std::collections::HashMap;
 use std::ffi::{CStr, CString};
+use std::fmt::{Debug, Formatter};
 use std::marker::PhantomData;
 use std::rc::Rc;
 use std::string::String;
-use std::sync::RwLock;
+use std::sync::{Arc, RwLock};
 
 use lazy_static::lazy_static;
 use libc::{c_char, c_int, c_short, c_void, time_t};
@@ -36,42 +37,63 @@ const O_WRONLY: c_int = 1;
 const O_APPEND: c_int = 1024;
 
 lazy_static! {
-    static ref HDFS_CACHE: RwLock<HashMap<String, HdfsFs>> = RwLock::new(HashMap::new());
+    static ref HDFS_MANAGER: HdfsManager = HdfsManager::new();
 }
 
-/// Hdfs Filesystem
-///
-/// It is basically thread safe because the native API for hdfsFs is thread-safe.
-#[derive(Clone)]
-pub struct HdfsFs {
-    url: String,
-    raw: hdfsFS,
-    _marker: PhantomData<()>,
+/// Create instance of HdfsFs with a global cache.
+/// For each namenode uri, only one instance will be created
+pub fn get_hdfs_by_full_path(path: &str) -> Result<Arc<HdfsFs>, HdfsErr> {
+    HDFS_MANAGER.get_hdfs_by_full_path(path)
 }
 
-impl HdfsFs {
-    /// Create instance of HdfsFs with a global cache.
-    /// For each namenode uri, only one instance will be created
-    pub fn new(path: &str) -> Result<HdfsFs, HdfsErr> {
+/// The default NameNode configuration will be used (from the XML configuration files)
+pub fn get_hdfs() -> Result<Arc<HdfsFs>, HdfsErr> {
+    HDFS_MANAGER.get_hdfs_by_full_path("default")
+}
+
+/// Remove an instance of HdfsFs from the cache by a specified path with uri
+pub fn unload_hdfs_cache_by_full_path(
+    path: &str,
+) -> Result<Option<Arc<HdfsFs>>, HdfsErr> {
+    HDFS_MANAGER.remove_hdfs_by_full_path(path)
+}
+
+/// Remove an instance of HdfsFs from the cache
+pub fn unload_hdfs_cache(hdfs: Arc<HdfsFs>) -> Result<Option<Arc<HdfsFs>>, HdfsErr> {
+    HDFS_MANAGER.remove_hdfs(hdfs)
+}
+
+/// Hdfs manager
+/// All of the HdfsFs instances will be managed in a singleton HdfsManager
+struct HdfsManager {
+    hdfs_cache: Arc<RwLock<HashMap<String, Arc<HdfsFs>>>>,
+}
+
+impl HdfsManager {
+    fn new() -> Self {
+        Self {
+            hdfs_cache: Arc::new(RwLock::new(HashMap::new())),
+        }
+    }
+
+    fn get_hdfs_by_full_path(&self, path: &str) -> Result<Arc<HdfsFs>, HdfsErr> {
         let namenode_uri = match path {
-            "default" => String::from("default"),
+            "default" => "default".to_owned(),
             _ => get_namenode_uri(path)?,
         };
 
-        {
-            // Get if exists
-            let cache = HDFS_CACHE.read().unwrap();
-            let ret = cache.get(&namenode_uri);
-            if let Some(hdfs_fs) = ret {
-                return Ok(hdfs_fs.clone());
-            }
+        // Get if already exists
+        if let Some(hdfs_fs) = {
+            let cache = self.hdfs_cache.read().unwrap();
+            cache.get(&namenode_uri).cloned()
+        } {
+            return Ok(hdfs_fs);
         }
 
-        let mut cache = HDFS_CACHE.write().unwrap();
-        let ret = cache.get(&namenode_uri);
-        return if let Some(hdfs_fs) = ret {
-            // Check again if exists
-            Ok(hdfs_fs.clone())
+        let mut cache = self.hdfs_cache.write().unwrap();
+        // Check again if exists
+        let ret = if let Some(hdfs_fs) = cache.get(&namenode_uri) {
+            hdfs_fs.clone()
         } else {
             let hdfs_fs = unsafe {
                 let hdfs_builder = hdfsNewBuilder();
@@ -85,31 +107,57 @@ impl HdfsFs {
                 return Err(HdfsErr::CannotConnectToNameNode(namenode_uri.clone()));
             }
 
-            let hdfs_fs = HdfsFs {
+            let hdfs_fs = Arc::new(HdfsFs {
                 url: namenode_uri.clone(),
                 raw: hdfs_fs,
                 _marker: PhantomData,
-            };
+            });
             cache.insert(namenode_uri.clone(), hdfs_fs.clone());
-            Ok(hdfs_fs)
+            hdfs_fs
         };
+
+        Ok(ret)
     }
 
-    /// The default NameNode configuration will be used (from the XML configuration files)
-    pub fn default() -> Result<HdfsFs, HdfsErr> {
-        HdfsFs::new("default")
-    }
-
-    pub fn remove(path: &str) -> Result<Option<HdfsFs>, HdfsErr> {
+    fn remove_hdfs_by_full_path(
+        &self,
+        path: &str,
+    ) -> Result<Option<Arc<HdfsFs>>, HdfsErr> {
         let namenode_uri = match path {
             "default" => String::from("default"),
             _ => get_namenode_uri(path)?,
         };
 
-        let mut cache = HDFS_CACHE.write().unwrap();
-        Ok(cache.remove(&namenode_uri))
+        self.remove_hdfs_inner(&namenode_uri)
     }
 
+    fn remove_hdfs(&self, hdfs: Arc<HdfsFs>) -> Result<Option<Arc<HdfsFs>>, HdfsErr> {
+        self.remove_hdfs_inner(hdfs.url())
+    }
+
+    fn remove_hdfs_inner(&self, hdfs_key: &str) -> Result<Option<Arc<HdfsFs>>, HdfsErr> {
+        let mut cache = self.hdfs_cache.write().unwrap();
+        Ok(cache.remove(hdfs_key))
+    }
+}
+
+/// Hdfs Filesystem
+///
+/// It is basically thread safe because the native API for hdfsFs is thread-safe.
+#[derive(Clone)]
+pub struct HdfsFs {
+    url: String,
+    raw: hdfsFS,
+    _marker: PhantomData<()>,
+}
+
+impl Debug for HdfsFs {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("HdfsFs").field("url", &self.url).finish()
+    }
+}
+
+impl HdfsFs {
     /// Get HDFS namenode url
     #[inline]
     pub fn url(&self) -> &str {
@@ -427,6 +475,15 @@ pub struct HdfsFile {
     _marker: PhantomData<()>,
 }
 
+impl Debug for HdfsFile {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        f.debug_struct("HdfsFile")
+            .field("url", &self.fs.url)
+            .field("path", &self.path)
+            .finish()
+    }
+}
+
 impl HdfsFile {
     /// Get HdfsFs
     #[inline]
@@ -562,6 +619,11 @@ impl HdfsFile {
     }
 }
 
+/// since HdfsFile is only the pointer to the file on Hdfs, here we implement Send+Sync trait
+unsafe impl Send for HdfsFile {}
+
+unsafe impl Sync for HdfsFile {}
+
 /// Interface that represents the client side information for a file or directory.
 pub struct FileStatus {
     raw: Rc<HdfsFileInfoPtr>,
@@ -600,7 +662,7 @@ impl FileStatus {
     /// Get the name of the file
     #[inline]
     pub fn name(&self) -> &str {
-        let slice = unsafe { CStr::from_ptr((&*self.ptr()).mName) }.to_bytes();
+        let slice = unsafe { CStr::from_ptr((*self.ptr()).mName) }.to_bytes();
         std::str::from_utf8(slice).unwrap()
     }
 
@@ -625,14 +687,14 @@ impl FileStatus {
     /// Get the owner of the file
     #[inline]
     pub fn owner(&self) -> &str {
-        let slice = unsafe { CStr::from_ptr((&*self.ptr()).mOwner) }.to_bytes();
+        let slice = unsafe { CStr::from_ptr((*self.ptr()).mOwner) }.to_bytes();
         std::str::from_utf8(slice).unwrap()
     }
 
     /// Get the group associated with the file
     #[inline]
     pub fn group(&self) -> &str {
-        let slice = unsafe { CStr::from_ptr((&*self.ptr()).mGroup) }.to_bytes();
+        let slice = unsafe { CStr::from_ptr((*self.ptr()).mGroup) }.to_bytes();
         std::str::from_utf8(slice).unwrap()
     }
 
@@ -643,6 +705,7 @@ impl FileStatus {
     }
 
     /// Get the length of this file, in bytes.
+    #[allow(clippy::len_without_is_empty)]
     #[inline]
     pub fn len(&self) -> usize {
         unsafe { &*self.ptr() }.mSize as usize
@@ -707,18 +770,19 @@ impl Drop for BlockHosts {
     }
 }
 
-pub const LOCAL_FS_SCHEME: &'static str = "file";
-pub const HDFS_FS_SCHEME: &'static str = "hdfs";
+pub const LOCAL_FS_SCHEME: &str = "file";
+pub const HDFS_FS_SCHEME: &str = "hdfs";
+pub const VIEW_FS_SCHEME: &str = "viewfs";
 
 #[inline]
 fn get_namenode_uri(path: &str) -> Result<String, HdfsErr> {
     match Url::parse(path) {
         Ok(url) => match url.scheme() {
             LOCAL_FS_SCHEME => Ok("file:///".to_string()),
-            HDFS_FS_SCHEME => {
+            HDFS_FS_SCHEME | VIEW_FS_SCHEME => {
                 if let Some(host) = url.host() {
                     let mut uri_builder = String::new();
-                    uri_builder.push_str(&(format!("{}://{}", HDFS_FS_SCHEME, host)));
+                    uri_builder.push_str(&(format!("{}://{}", url.scheme(), host)));
 
                     if let Some(port) = url.port() {
                         uri_builder.push_str(&(format!(":{}", port)));
@@ -736,14 +800,14 @@ fn get_namenode_uri(path: &str) -> Result<String, HdfsErr> {
 
 #[inline]
 pub fn get_uri(path: &str) -> Result<String, HdfsErr> {
-    let path = if path.starts_with("/") {
+    let path = if path.starts_with('/') {
         format!("{}://{}", LOCAL_FS_SCHEME, path)
     } else {
         path.to_string()
     };
     match Url::parse(&path) {
         Ok(url) => match url.scheme() {
-            LOCAL_FS_SCHEME | HDFS_FS_SCHEME => Ok(url.to_string()),
+            LOCAL_FS_SCHEME | HDFS_FS_SCHEME | VIEW_FS_SCHEME => Ok(url.to_string()),
             _ => Err(HdfsErr::InvalidUrl(path.to_string())),
         },
         Err(_) => Err(HdfsErr::InvalidUrl(path.to_string())),
@@ -752,13 +816,14 @@ pub fn get_uri(path: &str) -> Result<String, HdfsErr> {
 
 #[cfg(test)]
 mod test {
-    use crate::minidfs::get_dfs;
     use uuid::Uuid;
 
+    use crate::minidfs::get_dfs;
+
     #[cfg(feature = "use_existing_hdfs")]
     #[test]
     fn test_hdfs_default() {
-        let fs = super::HdfsFs::default().ok().unwrap();
+        let fs = super::get_hdfs().ok().unwrap();
 
         let uuid = Uuid::new_v4().to_string();
         let test_file = uuid.as_str();
