@@ -24,6 +24,7 @@ use std::str;
 use std::sync::Arc;
 
 use crate::err::HdfsErr;
+use crate::hdfs;
 use crate::hdfs::HdfsFs;
 use crate::native::*;
 
@@ -64,7 +65,7 @@ impl MiniDFS {
 
     fn stop(&self) {
         // remove hdfs from global cache
-        HdfsFs::remove(self.namenode_addr().as_str()).ok();
+        hdfs::unload_hdfs_cache_by_full_path(self.namenode_addr().as_str()).ok();
         unsafe {
             nmdShutdownClean(self.cluster);
             nmdFree(self.cluster);
@@ -73,15 +74,12 @@ impl MiniDFS {
 
     #[allow(dead_code)]
     fn wait_for_clusterup(&self) -> bool {
-        if unsafe { nmdWaitClusterUp(self.cluster) } == 0 {
-            true
-        } else {
-            false
-        }
+        unsafe { nmdWaitClusterUp(self.cluster) == 0 }
     }
 
+    #[allow(clippy::not_unsafe_ptr_arg_deref)]
     pub fn set_hdfs_builder(&self, builder: *mut hdfsBuilder) -> bool {
-        (unsafe { nmdConfigureHdfsBuilder(self.cluster, builder) } == 0)
+        unsafe { nmdConfigureHdfsBuilder(self.cluster, builder) == 0 }
     }
 
     pub fn namenode_port(&self) -> Option<i32> {
@@ -115,8 +113,8 @@ impl MiniDFS {
         }
     }
 
-    pub fn get_hdfs(&self) -> Result<HdfsFs, HdfsErr> {
-        HdfsFs::new(self.namenode_addr().as_str())
+    pub fn get_hdfs(&self) -> Result<Arc<HdfsFs>, HdfsErr> {
+        hdfs::get_hdfs_by_full_path(self.namenode_addr().as_str())
     }
 }
 
@@ -126,6 +124,5 @@ fn new_mini_dfs_conf() -> MiniDfsConf {
         webhdfsEnabled: 0,
         namenodeHttpPort: 0,
         configureShortCircuit: 0,
-        numDataNodes: 0,
     }
 }
